==> certmanager-model-v1alpha3-6.7.2-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha3/OrderSpecBuilder.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class OrderSpecBuilder extends OrderSpecFluentImpl<OrderSpecBuilder> implements VisitableBuilder<OrderSpec,OrderSpecBuilder>{
  public OrderSpecBuilder() {
    this(false);
  }
  public OrderSpecBuilder(Boolean validationEnabled) {
    this(new OrderSpec(), validationEnabled);
  }
  public OrderSpecBuilder(OrderSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public OrderSpecBuilder(OrderSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new OrderSpec(), validationEnabled);
  }
  public OrderSpecBuilder(OrderSpecFluent<?> fluent,OrderSpec instance) {
    this(fluent, instance, false);
  }
  public OrderSpecBuilder(OrderSpecFluent<?> fluent,OrderSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withCommonName(instance.getCommonName());
      fluent.withCsr(instance.getCsr());
      fluent.withDnsNames(instance.getDnsNames());
      fluent.withDuration(instance.getDuration());
      fluent.withIpAddresses(instance.getIpAddresses());
      fluent.withIssuerRef(instance.getIssuerRef());
    }
    this.validationEnabled = validationEnabled; 
  }
  public OrderSpecBuilder(OrderSpec instance) {
    this(instance,false);
  }
  public OrderSpecBuilder(OrderSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withCommonName(instance.getCommonName());
      this.withCsr(instance.getCsr());
      this.withDnsNames(instance.getDnsNames());
      this.withDuration(instance.getDuration());
      this.withIpAddresses(instance.getIpAddresses());
      this.withIssuerRef(instance.getIssuerRef());
    }
    this.validationEnabled = validationEnabled; 
  }
  OrderSpecFluent<?> fluent;
  Boolean validationEnabled;
  public OrderSpec build() {
    OrderSpec buildable = new OrderSpec(fluent.getCommonName(),fluent.getCsr(),fluent.getDnsNames(),fluent.getDuration(),fluent.getIpAddresses(),fluent.getIssuerRef());
    return buildable;
  }
  
}

==> certmanager-model-v1alpha3-6.8.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha3/OrderSpecBuilder.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class OrderSpecBuilder extends OrderSpecFluent<OrderSpecBuilder> implements VisitableBuilder<OrderSpec,OrderSpecBuilder>{
  public OrderSpecBuilder() {
    this(false);
  }
  public OrderSpecBuilder(Boolean validationEnabled) {
    this(new OrderSpec(), validationEnabled);
  }
  public OrderSpecBuilder(OrderSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public OrderSpecBuilder(OrderSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new OrderSpec(), validationEnabled);
  }
  public OrderSpecBuilder(OrderSpecFluent<?> fluent,OrderSpec instance) {
    this(fluent, instance, false);
  }
  public OrderSpecBuilder(OrderSpecFluent<?> fluent,OrderSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new OrderSpec());

    if (instance != null) {
      fluent.withCommonName(instance.getCommonName());
      fluent.withCsr(instance.getCsr());
      fluent.withDnsNames(instance.getDnsNames());
      fluent.withDuration(instance.getDuration());
      fluent.withIpAddresses(instance.getIpAddresses());
      fluent.withIssuerRef(instance.getIssuerRef());
      fluent.withCommonName(instance.getCommonName());
      fluent.withCsr(instance.getCsr());
      fluent.withDnsNames(instance.getDnsNames());
      fluent.withDuration(instance.getDuration());
      fluent.withIpAddresses(instance.getIpAddresses());
      fluent.withIssuerRef(instance.getIssuerRef());
    }
    this.validationEnabled = validationEnabled; 
  }
  public OrderSpecBuilder(OrderSpec instance) {
    this(instance,false);
  }
  public OrderSpecBuilder(OrderSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new OrderSpec());

    if (instance != null) {
      this.withCommonName(instance.getCommonName());
      this.withCsr(instance.getCsr());
      this.withDnsNames(instance.getDnsNames());
      this.withDuration(instance.getDuration());
      this.withIpAddresses(instance.getIpAddresses());
      this.withIssuerRef(instance.getIssuerRef());
      this.withCommonName(instance.getCommonName());
      this.withCsr(instance.getCsr());
      this.withDnsNames(instance.getDnsNames());
      this.withDuration(instance.getDuration());
      this.withIpAddresses(instance.getIpAddresses());
      this.withIssuerRef(instance.getIssuerRef());
    }
    this.validationEnabled = validationEnabled; 
  }
  OrderSpecFluent<?> fluent;
  Boolean validationEnabled;
  public OrderSpec build() {
    OrderSpec buildable = new OrderSpec(fluent.getCommonName(),fluent.getCsr(),fluent.getDnsNames(),fluent.getDuration(),fluent.getIpAddresses(),fluent.buildIssuerRef());
    return buildable;
  }
  
}
